.. bibliography multiple-comparison Bibliography

References
----------

Articles used in the creation of this module include

.. [Hansen] Hansen, P. R. (2005). A test for superior predictive ability. `Journal of Business & Economic Statistics`, 23(4).

.. [HansenLundeNason] Hansen, P. R., Lunde, A., & Nason, J. M. (2011). The model confidence set. `Econometrica`, 79(2), 453-497.

.. [RomanoWolf] Romano, J. P., & Wolf, M. (2005). Stepwise multiple testing as formalized data snooping. `Econometrica`, 73(4), 1237-1282.

.. [White] White, H. (2000). A reality check for data snooping. `Econometrica`, 68(5), 1097-1126.
